%define debug_package %{nil}

%define version_main %{version}
%define version_lite %{version}
%define ipv6_ver %{version}
%define ipv6_lite_ver %{version}
%define sha1sums_ver %{version}

%define ftp_ver %(echo %{version} | cut -d. -f1,2)
%define ftp_path http://shorewall.org/pub/shorewall/%{version_major}/%{name}-%{version}

%define name6 %{name}6

Summary:	Iptables-based firewall for Linux systems
Name:		shorewall
Version:	5.2.8
Release:	%mkrel 4
License:	GPLv2+ and LGPLv2.1+
Group:		System/Servers
URL:		http://www.shorewall.net/
Source0:	%{ftp_path}/%{name}-%{version}.tar.bz2
Source1:	%{ftp_path}/%{name}-lite-%{version_lite}.tar.bz2
Source2:	%{ftp_path}/%{name}-docs-html-%{version}.tar.bz2
Source3:	%{ftp_path}/%{name6}-%{ipv6_ver}.tar.bz2
Source4:	%{ftp_path}/%{name6}-lite-%{ipv6_lite_ver}.tar.bz2
Source5:	%{ftp_path}/%{sha1sums_ver}.sha1sums
Source6:	%{ftp_path}/%{name}-core-%{version}.tar.bz2
Patch4:		%{name}-4.4.23-allow-netmask-0.patch
Patch6:		shorewall-4.6.13.1-mga_fix.patch
# https://gitlab.com/shorewall/code/-/commit/ba87937f49010b873307240e3a6f22deac511d89
Patch7:		shorewall-switch-to-journald.patch
Requires:	iptables
Requires:	iproute2
Requires:	shorewall-core = %{version}-%{release}
Requires(post):	rpm-helper
Requires(preun): rpm-helper
BuildConflicts:	apt-common
BuildArch:	noarch

%description
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

%package core
Summary:	Shorewall core libraries
Group:		System/Servers
Conflicts:	shorewall < 4.5-3
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description core
An IPv6 enabled and capable Shoreline Firewall.


%package ipv6
Summary:	IPv6 capable Shorewall
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	iptables-ipv6
Requires:	iproute2
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description ipv6
An IPv6 enabled and capable Shoreline Firewall.

%package ipv6-lite
Summary:	Lite version of ipv6 shorewall
Group:		System/Servers
Requires:	%{name}-ipv6 = %{version}-%{release}
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description ipv6-lite
Shorewall IPv6 Lite is a companion product to Shorewall IPv6 that allows
network administrators to centralize the configuration of Shorewall-based
firewalls.

%package lite
Summary:	Lite version of shorewall
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description lite
Shorewall Lite is a companion product to Shorewall that allows network
administrators to centralize the configuration of Shorewall-based firewalls.

%package doc
Summary:	Firewall scripts
Group:		System/Servers

%description doc
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

This package contains the docs.

%prep
%setup -q -c -n %{name}-%{version}
%setup -q -T -D -a 1
%setup -q -T -D -a 2
%setup -q -T -D -a 3
%setup -q -T -D -a 4
%setup -q -T -D -a 6

pushd %{name}-%{version_main}
%patch4 -p1 -b .allow-netmask-0
popd

# use one patch for all (easiest fix)
for i in shorewall-%{version} shorewall6-%{version} \
    shorewall6-lite-%{version} shorewall-core-%{version} \
    shorewall-lite-%{version}; do
pushd $i
%patch6 -p1
popd
done

# another fixup
for i in shorewall-%{version} shorewall6-%{version} \
	shorewall6-lite-%{version} shorewall-lite-%{version}; do
pushd $i
cp default.debian.systemd sysconfig
popd
done

# switch to journal
%patch7 -p1

# replace obsolescent egrep and fgrep with grep -E and grep -F
sed -i -e 's/egrep/grep -E/g' $(grep -rl egrep)
sed -i -e 's/fgrep/grep -F/g' $(grep -rl fgrep)

%build
# (tpg) we do nothing here

%install
mkdir -p %{buildroot}%{_unitdir}

export PREFIX=%{buildroot}
export OWNER=`id -n -u`
export GROUP=`id -n -g`

export CONFDIR=%{_sysconfdir}/%{name}

pushd %{name}-core-%{version_main}
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

pushd %{name}-%{version_main}
# (blino) enable startup (new setting as of 2.1.3)
perl -pi -e 's/STARTUP_ENABLED=.*/STARTUP_ENABLED=Yes/' configfiles/%{name}.conf

# Keep synced with net.ipv4.ip_forward var in /etc/sysctl.conf
perl -pi -e 's/IP_FORWARDING=.*/IP_FORWARDING=Keep/' configfiles/%{name}.conf

# blank Internal option
perl -pi -e 's/TC_ENABLED=Internal/TC_ENABLED=/' configfiles/%{name}.conf

# (tpg) do the optimizations
perl -pi -e 's/OPTIMIZE=.*/OPTIMIZE=1/' configfiles/%{name}.conf

# (tpg) set config path
perl -pi -e 's#CONFIG_PATH=.*#CONFIG_PATH=configfiles/%{/g_sysconfdir}/%{name}#' configpath

# (lmenut) mga kernel modules are compressed by default (mga #1147)
perl -pi -e 's#MODULE_SUFFIX=.*#MODULE_SUFFIX="ko ko.xz ko.gz"#' configfiles/%{name}.conf

# (alien) have accounting by default in the mangle table
perl -pi -e 's#ACCOUNTING_TABLE=.*#ACCOUNTING_TABLE=mangle#' configfiles/%{name}.conf

./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}

# let's do the install
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
install -m 644 *.service %{buildroot}%{_unitdir}
popd

#(tpg) IPv6
pushd %{name6}-%{ipv6_ver}
# (blino) enable startup (new setting as of 2.1.3)
perl -pi -e 's/STARTUP_ENABLED=.*/STARTUP_ENABLED=Yes/' configfiles/%{name6}.conf
# Keep synced with net.ipv4.ip_forward var in /etc/sysctl.conf
perl -pi -e 's/IP_FORWARDING=.*/IP_FORWARDING=Keep/' configfiles/%{name6}.conf
# (lmenut) mga kernel modules are compressed by default (mga #1147)
perl -pi -e 's#MODULE_SUFFIX=.*#MODULE_SUFFIX="ko ko.xz ko.gz"#' configfiles/%{name6}.conf
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh
install -m 644 *.service %{buildroot}%{_unitdir}
popd

pushd %{name6}-lite-%{ipv6_lite_ver}
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh
install -m 644 *.service %{buildroot}%{_unitdir}
popd

pushd %{name}-lite-%{version_lite}
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh
install -m 644 *.service %{buildroot}%{_unitdir}
popd

# Suppress automatic replacement of "echo" by "gprintf" in the shorewall
# startup script by RPM. This automatic replacement is broken.
export DONT_GPRINTIFY=1

#(tpg) looks like these files are needed
touch %{buildroot}/%{_var}/lib/shorewall/{chains,nat,proxyarp,restarted,zones,restore-base,restore-tail,state,.modules,.modulesdir,.iptables-restore-input,.start,.restart,.restore}
touch %{buildroot}/%{_var}/lib/shorewall-lite/firewall

#(tpg) ipv6
touch %{buildroot}/%{_var}/lib/%{name6}/{chains,restarted,zones,restore-base,restore-tail,state,.modules,.modulesdir,.iptables-restore-input,.start,.restart,.restore}
touch %{buildroot}/%{_var}/lib/%{name6}-lite/firewall

#remove unused files because of % exclude misbehaviour
rm -f %{buildroot}%{_datadir}/%{name6}/configfiles/*
rm -f %{buildroot}%{_datadir}/shorewall/configfiles/*

# Remove sysv init file
rm -f %{buildroot}%{_initrddir}/%{name}

# Don't install systemd service in /lib/systemd
rm -f %{buildroot}/lib/systemd/system/shorewall.service
rm -f %{buildroot}/lib/systemd/system/shorewall-lite.service
rm -f %{buildroot}/lib/systemd/system/shorewall6.service
rm -f %{buildroot}/lib/systemd/system/shorewall6-lite.service

# (tmb) allow outgoing traffic on any interface by default (mga#10947)
# (cg) drop the ?FORMAT 2 line as it disagrees with 'detect' (mga#11928)
perl -n -i -e 'print unless m!^?FORMAT 2$!' %{buildroot}%{_sysconfdir}/%{name}/interfaces
echo "net	+	detect" >> %{buildroot}%{_sysconfdir}/%{name}/interfaces
perl -n -i -e 'print unless m!^?FORMAT 2$!' %{buildroot}%{_sysconfdir}/%{name6}/interfaces
echo "net	+	detect" >> %{buildroot}%{_sysconfdir}/%{name6}/interfaces

# fix permission (mga#26908)
chmod -R 700 %{buildroot}%{_sysconfdir}/%{name6}
chmod -R 700 %{buildroot}%{_sysconfdir}/%{name6}-lite
chmod -R 700 %{buildroot}%{_sysconfdir}/%{name}-lite

%post
if [ "$1" -gt 1 ] ; then
  perl -pi -e 's#MODULE_SUFFIX=ko$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name}/%{name}.conf
  perl -pi -e 's#MODULE_SUFFIX=\"ko ko.gz\"$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name}/%{name}.conf
fi
%_post_service shorewall

%create_ghostfile %{_var}/lib/%{name}/chains root root 644
%create_ghostfile %{_var}/lib/%{name}/nat root root 644
%create_ghostfile %{_var}/lib/%{name}/proxyarp root root 644
%create_ghostfile %{_var}/lib/%{name}/restarted root root 644
%create_ghostfile %{_var}/lib/%{name}/zones root root 644
%create_ghostfile %{_var}/lib/%{name}/restore-base root root 644
%create_ghostfile %{_var}/lib/%{name}/restore-tail root root 644
%create_ghostfile %{_var}/lib/%{name}/state root root 644
%create_ghostfile %{_var}/lib/%{name}/.modules root root 644
%create_ghostfile %{_var}/lib/%{name}/.modulesdir root root 644
%create_ghostfile %{_var}/lib/%{name}/.iptables-restore-input root root 644
%create_ghostfile %{_var}/lib/%{name}/.restart root root 700
%create_ghostfile %{_var}/lib/%{name}/.restore root root 700
%create_ghostfile %{_var}/lib/%{name}/.start root root 700

%preun
%_preun_service %{name}
if [ $1 = 0 ] ; then
  rm -f %{_sysconfdir}/%{name}/startup_disabled
  rm -f %{_var}/lib/%{name}/*
fi

%post lite
%_post_service %{name}-lite
%create_ghostfile %{_var}/lib/%{name}-lite/firewall root root 644

%preun lite
%_preun_service %{name}-lite

%post ipv6
if [ "$1" -gt 1 ] ; then
  perl -pi -e 's#MODULE_SUFFIX=ko$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name6}/%{name6}.conf
  perl -pi -e 's#MODULE_SUFFIX=\"ko ko.gz\"$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name6}/%{name6}.conf
fi
%_post_service %{name6}

%create_ghostfile %{_var}/lib/%{name6}/chains root root 644
%create_ghostfile %{_var}/lib/%{name6}/restarted root root 644
%create_ghostfile %{_var}/lib/%{name6}/zones root root 644
%create_ghostfile %{_var}/lib/%{name6}/restore-base root root 644
%create_ghostfile %{_var}/lib/%{name6}/restore-tail root root 644
%create_ghostfile %{_var}/lib/%{name6}/state root root 644
%create_ghostfile %{_var}/lib/%{name6}/.modules root root 644
%create_ghostfile %{_var}/lib/%{name6}/.modulesdir root root 644
%create_ghostfile %{_var}/lib/%{name6}/.iptables-restore-input root root 644
%create_ghostfile %{_var}/lib/%{name6}/.restart root root 700
%create_ghostfile %{_var}/lib/%{name6}/.restore root root 700
%create_ghostfile %{_var}/lib/%{name6}/.start root root 700

%preun ipv6
%_preun_service %{name6}
if [ $1 = 0 ] ; then
  rm -f %{_sysconfdir}/%{name6}/startup_disabled
  rm -f %{_var}/lib/%{name6}/*
fi

%post ipv6-lite
%_post_service %{name6}-lite
%create_ghostfile %{_var}/lib/%{name6}-lite/firewall root root 644

%preun ipv6-lite
%_preun_service %{name6}-lite

%files
%doc %{name}-%{version_main}/{changelog.txt,releasenotes.txt,Samples}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_datadir}/%{name}
%dir %attr(755,root,root) %{_var}/lib/%{name}
%ghost %{_var}/lib/%{name}/*
%ghost %{_var}/lib/%{name}/.??*
%config %{_sysconfdir}/logrotate.d/%{name}
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}
%{_datadir}/%{name}/action*
%{_datadir}/%{name}/configpath
%{_datadir}/%{name}/helpers
%{_datadir}/%{name}/lib.cli-std
%{_datadir}/%{name}/lib.runtime
%{_datadir}/%{name}/macro.*
%{_datadir}/%{name}/version
%dir %{_libexecdir}/%{name}/
%{_libexecdir}/%{name}/getparams
%{_libexecdir}/%{name}/wait4ifup
%{_libexecdir}/%{name}/compiler.pl
%{_mandir}/man5/%{name}-accounting.5.*
%{_mandir}/man5/%{name}-actions.5.*
%{_mandir}/man5/%{name}-addresses.5.*
%{_mandir}/man5/%{name}-ecn.5.*
%{_mandir}/man5/%{name}-exclusion.5.*
%{_mandir}/man5/%{name}-files.5.*
%{_mandir}/man5/%{name}-hosts.5.*
%{_mandir}/man5/%{name}-interfaces.5.*
%{_mandir}/man5/%{name}-ipsets.5.*
%{_mandir}/man5/%{name}-logging.5.*
%{_mandir}/man5/%{name}-maclist.5.*
%{_mandir}/man5/%{name}-mangle.5.*
%{_mandir}/man5/%{name}-modules.5.*
%{_mandir}/man5/%{name}-names.5.*
%{_mandir}/man5/%{name}-nat.5.*
%{_mandir}/man5/%{name}-nesting.5.*
%{_mandir}/man5/%{name}-netmap.5.*
%{_mandir}/man5/%{name}-params.5.*
%{_mandir}/man5/%{name}-policy.5.*
%{_mandir}/man5/%{name}-providers.5.*
%{_mandir}/man5/%{name}-proxyarp.5.*
%{_mandir}/man5/%{name}-proxyndp.5.*
%{_mandir}/man5/%{name}-routes.5.*
%{_mandir}/man5/%{name}-rules.5.*
%{_mandir}/man5/%{name}-secmarks.5.*
%{_mandir}/man5/%{name}-snat.5.*
%{_mandir}/man5/%{name}-tcclasses.5.*
%{_mandir}/man5/%{name}-tcinterfaces.5.*
%{_mandir}/man5/%{name}-tcpri.5.*
%{_mandir}/man5/%{name}-tcdevices.5.*
%{_mandir}/man5/%{name}-tcfilters.5.*
%{_mandir}/man5/%{name}-tunnels.5.*
%{_mandir}/man5/%{name}-vardir.5.*
%{_mandir}/man5/%{name}-zones.5.*
%{_mandir}/man5/%{name}.conf.5.*
%{_mandir}/man8/%{name}.8.*
%{_mandir}/man8/%{name}-init.8.*
%{_mandir}/man5/%{name}-blrules.5.*
%{_mandir}/man5/%{name}-conntrack.5.*
%{_mandir}/man5/%{name}-rtrules.5.*
%{_mandir}/man5/%{name}-stoppedrules.5.*
%{_mandir}/man5/%{name}-arprules.5*
%{_datadir}/perl5/vendor_perl/Shorewall/*.pm
%{_datadir}/shorewall/prog.footer
%{_unitdir}/shorewall.service

%files ipv6
%doc %{name6}-%{ipv6_ver}/{changelog.txt,releasenotes.txt,tunnel,ipsecvpn,Samples6}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name6}
%dir %{_sysconfdir}/%{name6}
%dir %{_datadir}/%{name6}
%dir %attr(755,root,root) %{_var}/lib/%{name6}
%ghost %{_var}/lib/%{name6}/*
%ghost %{_var}/lib/%{name6}/.??*
%config(noreplace) %{_sysconfdir}/%{name6}/*
%config %{_sysconfdir}/logrotate.d/%{name6}
%{_sbindir}/%{name6}
%{_datadir}/%{name6}/action*
%{_datadir}/%{name6}/configpath
%{_datadir}/%{name6}/functions
%{_datadir}/%{name6}/helpers
%{_datadir}/%{name6}/lib.*
%{_datadir}/%{name6}/macro.*
%{_datadir}/%{name6}/version
%{_mandir}/man5/%{name6}-accounting.5.*
%{_mandir}/man5/%{name6}-actions.5.*
%{_mandir}/man5/%{name6}-blacklist.5.*
%{_mandir}/man5/%{name6}-exclusion.5.*
%{_mandir}/man5/%{name6}-hosts.5.*
%{_mandir}/man5/%{name6}-interfaces.5.*
%{_mandir}/man5/%{name6}-ipsets.5.*
%{_mandir}/man5/%{name6}-maclist.5.*
%{_mandir}/man5/%{name6}-mangle.5.*
%{_mandir}/man5/%{name6}-modules.5.*
%{_mandir}/man5/%{name6}-nesting.5.*
%{_mandir}/man5/%{name6}-nat.5.*
%{_mandir}/man5/%{name6}-params.5.*
%{_mandir}/man5/%{name6}-policy.5.*
%{_mandir}/man5/%{name6}-providers.5.*
%{_mandir}/man5/%{name6}-proxyndp.5.*
%{_mandir}/man5/%{name6}-routes.5.*
%{_mandir}/man5/%{name6}-routestopped.5.*
%{_mandir}/man5/%{name6}-rules.5.*
%{_mandir}/man5/%{name6}-secmarks.5.*
%{_mandir}/man5/%{name6}-snat.5.*
%{_mandir}/man5/%{name6}-tcclasses.5.*
%{_mandir}/man5/%{name6}-tcdevices.5.*
%{_mandir}/man5/%{name6}-tcfilters.5.*
%{_mandir}/man5/%{name6}-tcinterfaces.5.*
%{_mandir}/man5/%{name6}-tcpri.5.*
%{_mandir}/man5/%{name6}-tcrules.5.*
%{_mandir}/man5/%{name6}-tos.5.*
%{_mandir}/man5/%{name6}-tunnels.5.*
%{_mandir}/man5/%{name6}-vardir.5.*
%{_mandir}/man5/%{name6}-zones.5.*
%{_mandir}/man5/%{name6}.conf.5.*
%{_mandir}/man8/%{name6}.8.*
%{_mandir}/man5/%{name6}-blrules.5.*
%{_mandir}/man5/%{name6}-conntrack.5.*
%{_mandir}/man5/%{name6}-rtrules.5.*
%{_mandir}/man5/%{name6}-stoppedrules.5.*
%{_mandir}/man5/%{name6}-netmap.5.*
%{_mandir}/man5/%{name6}-masq.5*
%{_unitdir}/shorewall6.service

%files lite
%doc %{name}-lite-%{version_lite}/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}-lite
%dir %{_sysconfdir}/%{name}-lite
%dir %{_datadir}/%{name}-lite
%dir %attr(755,root,root) %{_var}/lib/%{name}-lite
%ghost %{_var}/lib/%{name}-lite/*
%config(noreplace) %{_sysconfdir}/%{name}-lite/*
%config %{_sysconfdir}/logrotate.d/%{name}-lite
%{_sbindir}/%{name}-lite
%{_datadir}/%{name}-lite/configpath
%{_datadir}/%{name}-lite/functions
%{_datadir}/%{name}-lite/helpers
%{_datadir}/%{name}-lite/lib.*
%{_datadir}/%{name}-lite/version
%{_mandir}/man5/%{name}-lite*
%{_mandir}/man8/%{name}-lite*
%dir %{_libexecdir}/%{name}-lite/
%{_libexecdir}/%{name}-lite/shorecap
%{_unitdir}/shorewall-lite.service

%files ipv6-lite
%doc %{name6}-lite-%{ipv6_lite_ver}/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name6}-lite
%dir %{_sysconfdir}/%{name6}-lite
%dir %{_datadir}/%{name6}-lite
%dir %attr(755,root,root) %{_var}/lib/%{name6}-lite
%ghost %{_var}/lib/%{name6}-lite/*
%config(noreplace) %{_sysconfdir}/%{name6}-lite/*
%config %{_sysconfdir}/logrotate.d/%{name6}-lite
%{_sbindir}/%{name6}-lite
%{_datadir}/%{name6}-lite/configpath
%{_datadir}/%{name6}-lite/functions
%{_datadir}/%{name6}-lite/helpers
%{_datadir}/%{name6}-lite/lib.*
%dir %{_libexecdir}/%{name6}-lite/
%{_libexecdir}/%{name6}-lite/shorecap
%{_datadir}/%{name6}-lite/version
%{_mandir}/man5/%{name6}-lite*
%{_mandir}/man8/%{name6}-lite*
%{_unitdir}/shorewall6-lite.service

%files doc
%doc %{name}-docs-html-%{version}/*

%files core
%doc shorewall-core-%{version}/{COPYING,changelog.txt,releasenotes.txt}
%dir %{_datadir}/shorewall/
%attr(755,root,root) /sbin/shorewall
%{_datadir}/shorewall/coreversion
%{_datadir}/shorewall/functions
%{_datadir}/shorewall/lib.base
%{_datadir}/shorewall/lib.cli
%{_datadir}/shorewall/lib.common
%{_datadir}/shorewall/lib.core
%{_datadir}/shorewall/shorewallrc



%changelog
* Sat Dec 31 2022 wally <wally> 5.2.8-4.mga9
+ Revision: 1928421
- replace egrep and fgrep with grep -E and grep -F in scriptlets (mga#31334)

* Mon Mar 21 2022 umeabot <umeabot> 5.2.8-3.mga9
+ Revision: 1813868
- Mageia 9 Mass Rebuild
+ wally <wally>
- own directories under /usr/libexec/

* Sun Jan 31 2021 tmb <tmb> 5.2.8-2.mga8
+ Revision: 1674263
- switch from syslog to journal (mga#27096)

* Wed Nov 18 2020 luigiwalser <luigiwalser> 5.2.8-1.mga8
+ Revision: 1647252
- 5.2.8

* Fri Aug 14 2020 neoclust <neoclust> 5.2.7-2.mga8
+ Revision: 1614087
- Rebuild because of missing rpms

* Fri Aug 07 2020 bcornec <bcornec> 5.2.7-1.mga8
+ Revision: 1611917
- Update to upstream shorewall 5.2.7

* Tue Jul 07 2020 daviddavid <daviddavid> 5.2.3.4-3.mga8
+ Revision: 1602801
- set '/etc/shorewall6' permission to 700 (mga#26908)

* Tue Feb 18 2020 umeabot <umeabot> 5.2.3.4-2.mga8
+ Revision: 1538426
- Mageia 8 Mass Rebuild

* Thu Nov 21 2019 daviddavid <daviddavid> 5.2.3.4-1.mga8
+ Revision: 1461957
- new version: 5.2.3.4

* Mon May 13 2019 luigiwalser <luigiwalser> 5.2.3.3-1.mga7
+ Revision: 1397530
- 5.2.3.3

* Sun Feb 17 2019 luigiwalser <luigiwalser> 5.2.3-1.mga7
+ Revision: 1368004
- 5.2.3

* Mon Jan 21 2019 luigiwalser <luigiwalser> 5.2.2-1.mga7
+ Revision: 1358604
- 5.2.2

* Fri Dec 28 2018 luigiwalser <luigiwalser> 5.2.1.4-1.mga7
+ Revision: 1345696
- 5.2.1.4

* Fri Sep 21 2018 umeabot <umeabot> 5.1.12.4-2.mga7
+ Revision: 1291480
- Mageia 7 Mass Rebuild

* Sun Apr 22 2018 kekepower <kekepower> 5.1.12.4-1.mga7
+ Revision: 1221280
- Update to version 5.1.12.4

* Tue Jan 02 2018 mokraemer <mokraemer> 5.1.10.2-1.mga7
+ Revision: 1189358
- updated shorewall (mga#21845)

* Tue May 16 2017 luigiwalser <luigiwalser> 5.0.15.6-1.mga6
+ Revision: 1102252
- 5.0.15.6
- download sources via http

* Sun Jan 01 2017 luigiwalser <luigiwalser> 5.0.15.2-1.mga6
+ Revision: 1078933
- 5.0.15.2

* Sat Dec 17 2016 luigiwalser <luigiwalser> 5.0.15.1-1.mga6
+ Revision: 1075753
- 5.0.15.1

* Fri Nov 11 2016 luigiwalser <luigiwalser> 5.0.14.1-1.mga6
+ Revision: 1066573
- 5.0.14.1

* Sat Sep 10 2016 luigiwalser <luigiwalser> 5.0.11-1.mga6
+ Revision: 1051350
- 5.0.11

* Wed Aug 10 2016 luigiwalser <luigiwalser> 5.0.10.1-1.mga6
+ Revision: 1045403
- 5.0.10.1

* Thu Jun 23 2016 tmb <tmb> 5.0.9.2-1.mga6
+ Revision: 1037250
- update to 5.0.9.2

* Fri May 06 2016 tmb <tmb> 5.0.8.2-0.1.mga6
+ Revision: 1009743
- update to 5.0.8.2

* Fri Feb 19 2016 umeabot <umeabot> 4.6.13.1-2.mga6
+ Revision: 970282
- Mageia 6 Mass Rebuild

* Fri Oct 02 2015 tmb <tmb> 4.6.13.1-1.mga6
+ Revision: 885694
- update to 4.6.13.1

* Wed Oct 15 2014 umeabot <umeabot> 4.6.3.4-2.mga5
+ Revision: 750832
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 luigiwalser <luigiwalser> 4.6.3.4-1.mga5
+ Revision: 737611
- 4.6.3.4

* Tue Sep 16 2014 umeabot <umeabot> 4.6.3.2-2.mga5
+ Revision: 689142
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 4.6.3.2-1.mga5
+ Revision: 672328
- 4.6.3.2

* Mon Sep 01 2014 luigiwalser <luigiwalser> 4.6.3.1-1.mga5
+ Revision: 670228
- 4.6.3.1
- rediff patch 6
- add shorewall-mangle man pages to files list

* Thu Mar 13 2014 dams <dams> 4.5.21.7-1.mga5
+ Revision: 603214
- new version 4.5.21.7
+ colin <colin>
- Drop 'FORMAT 2' in the interfaces files as conflicts with detect mode mga#11928

* Sat Jan 25 2014 colin <colin> 4.5.21.5-1.mga4
+ Revision: 568200
- Update to shorewall 4.5.21.5 to solve parallel ip[6]tables invocations (mga#11928)

* Sat Dec 21 2013 lmenut <lmenut> 4.5.20-3.mga4
+ Revision: 559329
- fix upgrade test in %%post

* Sat Oct 19 2013 umeabot <umeabot> 4.5.20-2.mga4
+ Revision: 533660
- Mageia 4 Mass Rebuild

* Tue Sep 03 2013 oden <oden> 4.5.20-1.mga4
+ Revision: 474647
- 4.5.20
- P6: make it recognize mageia as redhat

* Sat Aug 10 2013 tmb <tmb> 4.5.10.1-5.mga4
+ Revision: 465126
- allow outgoing traffic on any interface by default (mga #10947)

* Tue Feb 05 2013 tmb <tmb> 4.5.10.1-4.mga3
+ Revision: 394718
- fix typo in .restore (P5)

* Sun Feb 03 2013 anssi <anssi> 4.5.10.1-3.mga3
+ Revision: 394246
- remove files from shorewall that conflict with shorewall-core
- versionize requires on shorewall-core
- add missing Conlicts entry due to file moves

* Mon Jan 14 2013 umeabot <umeabot> 4.5.10.1-2.mga3
+ Revision: 381983
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 solbu <solbu> 4.5.10.1-1.mga3
+ Revision: 343300
- Fix unpackaged files
+ kamil <kamil>
- requires shorewall-core by shorewall, -lite and shorewall6 equivalents
- add /etc/sysconfig/.. to %%files
- add systemd files to %%files
- remove 'hash-bang' patch
- remove dash dependencies
- try to adjust LIBEXEC
- adapt .spec for usr move and systemd
- define SYSTEMD and SBINDIR in ./configure.pl
- remove P0, P1, P2, P3
- update %%files
- new subpackage: shorewall-core
- disable P0, P1, P2, P3
- new installation ("Versions 4.5.2 and Later")
- fix setting ACCOUNTING_TABLE to mangle, there was a typo: ACCOUNT_TABLE
- don't enable IPV6, it's enabled by default
- don't set SHOREWALL_COMPILER value - (old, not configrable anymore)
- stop using versioning requires of iptables (old)
- remove README.4.4.0.upgrade.urpmi from %%files
- remove old README.4.4.0.upgrade.urpmi
- remove old Obsoletes and conflicts
- new version 4.5.10.1 and update ftp paths

* Mon Apr 09 2012 alien <alien> 4.4.23.1-9.mga2
+ Revision: 229827
- ACCOUNT target allows 0.0.0.0/0

* Sun Apr 08 2012 alien <alien> 4.4.23.1-8.mga2
+ Revision: 229729
- have accounting by default in the mangle table

* Tue Mar 20 2012 blino <blino> 4.4.23.1-7.mga2
+ Revision: 225082
- do not attempt to create /1 file in post script

* Sat Mar 10 2012 kamil <kamil> 4.4.23.1-6.mga2
+ Revision: 222372
- fix license - samples are licensed under LGPLv2.1+
- clean .spec a bit

* Wed Feb 15 2012 lmenut <lmenut> 4.4.23.1-5.mga2
+ Revision: 209012
- allow loading of xz compressed kernel modules

* Sun Jan 08 2012 lmenut <lmenut> 4.4.23.1-4.mga2
+ Revision: 193495
- fix MODULE_SUFFIX (shorewall.conf) in post upgrade
  (complete the fix for mga #1147 and #1903)

* Tue Jan 03 2012 lmenut <lmenut> 4.4.23.1-3.mga2
+ Revision: 189975
- allow to load compressed modules (thanks to Christophe Mace)
  (fix cant connect ftp through firewall - mga #1147)
- really modify default shorewall6.conf

* Sat Dec 03 2011 blino <blino> 4.4.23.1-2.mga2
+ Revision: 175272
- do not try to add LAST LINE comments anymore in config files:
- the command in the spec file was broken (missing leading dir)
- drakx-net will be fixed to deal without these markers

* Mon Sep 12 2011 tv <tv> 4.4.23.1-1.mga2
+ Revision: 142806
- new release
- use function to add comment in config files instead of a patch 4 (tpg)
- drop patch 5 (merged)

* Mon Jun 13 2011 ahmad <ahmad> 4.4.20.2-2.mga2
+ Revision: 105829
- Add a patch from upstream to to quell compiler warnings with perl-5.14 (mga#1775)

* Mon Jun 13 2011 ahmad <ahmad> 4.4.20.2-1.mga2
+ Revision: 105489
- Update to 4.4.20.2

* Sun May 15 2011 pterjan <pterjan> 4.4.19.1-3.mga1
+ Revision: 99032
- Rebuild for fixed find-requires

* Tue May 03 2011 tmb <tmb> 4.4.19.1-2.mga1
+ Revision: 94462
- Add requires on dash as its defined as SHOREWALL_SHELL (mdv #63183)

* Mon Apr 25 2011 ahmad <ahmad> 4.4.19.1-1.mga1
+ Revision: 90647
- Update to 4.4.19.1
- Update the file list
- Rediff the "comment" patch
- Drop the module_suffix patch (Mandriva)

* Fri Feb 11 2011 ennael <ennael> 4.4.12.1-1.mga1
+ Revision: 50105
- remove unused files
- imported package shorewall


* Sun Aug 29 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 4.4.12.1-1mdv2011.0
+ Revision: 574000
- update to new version 4.4.12.1
- redeiff patches 4 i 5
- remove requires on dash, no need to redundant requires

* Thu Aug 05 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 4.4.11-2mdv2011.0
+ Revision: 566063
- switch default shebang to dash (speed up is almost 1 second)
- add requires to dash

* Thu Jul 15 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 4.4.11-1mdv2011.0
+ Revision: 553762
- update to new version 4.4.11
- rediff patches 4 and 5
- fix file list

* Tue May 18 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4.9-2mdv2010.1
+ Revision: 545278
- P5: use default kernel module suffix.

* Sat May 08 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4.9-1mdv2010.1
+ Revision: 543542
- Updated to 4.4.9.

* Fri Mar 26 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4.8-1mdv2010.1
+ Revision: 527662
- Updated to 4.4.8.

* Tue Feb 23 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4.7-2mdv2010.1
+ Revision: 510406
- Updated to 4.4.7.5.

* Wed Feb 17 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4.7-1mdv2010.1
+ Revision: 507244
- Updated to 4.4.7.4.

* Mon Jan 18 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4.6-1mdv2010.1
+ Revision: 493159
- New version 4.4.6.

* Thu Dec 24 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.5-2mdv2010.1
+ Revision: 482167
- New version 4.4.5.4.

* Wed Dec 23 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.5-1mdv2010.1
+ Revision: 481680
- Updated to 4.4.5.3.
  Added logrotate files.

* Tue Nov 10 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.3-1mdv2010.1
+ Revision: 464079
- Updated to 4.4.3.

* Sun Oct 04 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.2-2mdv2010.0
+ Revision: 453691
- Updated shorewall subpackage to 4.4.2.2.
- Updated to 4.4.2.

* Fri Sep 04 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.1-1mdv2010.0
+ Revision: 431580
- Updated to 4.4.1.2.

* Tue Aug 25 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.0-3mdv2010.0
+ Revision: 421023
- Adding missing comments to delimit last lines in 4.4.0 config files (breaks
  drakfirewall sometimes).

* Sun Aug 16 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.0-2mdv2010.0
+ Revision: 417118
- Added README.urpmi regarding 4.4.0 version upgrade.

* Sun Aug 16 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.4.0-1mdv2010.0
+ Revision: 416738
- Updated to shorewall-4.4.0 final.
  Obsoleting shorewall-common, shorewall-perl and shorewall-shell,
  as they are no loger supported.

* Sun Jun 21 2009 Frederik Himpe <fhimpe@mandriva.org> 4.2.10-1mdv2010.0
+ Revision: 387591
- Update to new version 4.2.10

* Sat May 16 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.9-1mdv2010.0
+ Revision: 376307
- Updated to 4.2.9.

* Fri Apr 17 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.8-2mdv2009.1
+ Revision: 367920
- Updated shorewall-perl to 4.2.8.1 (bugfix).

* Thu Apr 16 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.8-1mdv2009.1
+ Revision: 367755
- Added 4.2.8.sha1sums.
- Updated to version 4.2.8.

* Mon Mar 09 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.6-2mdv2009.1
+ Revision: 353315
- Installing correct permissions for shorewall config files.

* Sun Feb 15 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.6-1mdv2009.1
+ Revision: 340686
- Updated to new upstream 4.2.6.

* Mon Feb 09 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.5-3mdv2009.1
+ Revision: 338872
- Updated shorewall-perl to version 5.2.5.3 and shorewall6 to version 4.2.5.1.

* Sat Jan 24 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.5-2mdv2009.1
+ Revision: 333163
- Now ipv6 version of shorewall actually installs.

* Thu Jan 22 2009 Eugeni Dodonov <eugeni@mandriva.com> 4.2.5-1mdv2009.1
+ Revision: 332620
- Update to new version 4.2.5.

* Tue Jan 20 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 4.2.4-2mdv2009.1
+ Revision: 331781
- update shorewall-perl to 4.2.4.6 version

* Sat Jan 03 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 4.2.4-1mdv2009.1
+ Revision: 323534
- update to new version 4.2.4
- this release introduces IPv6 support in Shoreline firewall (needs kernel-2.6.25 and iptables-1.4.1)
  o shorewall-ipv6
  o shorewall-ipv6-lite
- adapt spec file for new subpackages
- rediff both patches and add new ones for new subpackages
- shorewall-perl and shorewall-shell does not require rpm-helper

* Sun Nov 30 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.2.2-1mdv2009.1
+ Revision: 308523
- update to new version 4.2.2

* Wed Nov 05 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.2.1-1mdv2009.1
+ Revision: 300090
- update to new version 4.2.1(.1)

* Sun Oct 12 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.2.0-2mdv2009.1
+ Revision: 293005
- enable IPv6 support

* Sun Oct 12 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.2.0-1mdv2009.1
+ Revision: 292841
- update to new version 4.2.0

* Tue Sep 23 2008 Olivier Blin <oblin@mandriva.com> 4.0.13-5mdv2009.0
+ Revision: 287298
- revert running iptables check, it should be done in iptables post instead of running this every boot

* Thu Aug 28 2008 Oden Eriksson <oeriksson@mandriva.com> 4.0.13-4mdv2009.0
+ Revision: 276811
- fix #42579 (shorewall-perl complains of missing Mult-port Match support in kernel/iptables)
- fix spec file bug in the shorewall-lite %%post script

* Mon Aug 04 2008 Frederik Himpe <fhimpe@mandriva.org> 4.0.13-3mdv2009.0
+ Revision: 263505
- New upstream version 4.0.13

* Wed Jun 18 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.11-3mdv2009.0
+ Revision: 225451
- update shorewall-perl to new version 4.0.11.1

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Thu May 29 2008 Gustavo De Nardin <gustavodn@mandriva.com> 4.0.11-2mdv2009.0
+ Revision: 213149
- fix missing requirement on iptables-ipv6, for Shorewall to be able to
  "handle" IPv6 (currently, DISABLE_IPV6=Yes in /etc/shorewall/shorewall.conf)

* Sun May 25 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.11-1mdv2009.0
+ Revision: 211074
- update to new version 4.0.11

* Tue Mar 11 2008 Olivier Blin <oblin@mandriva.com> 4.0.9-3mdv2008.1
+ Revision: 185827
- do not package dirs as ghost (#38105)
- do not include . and .. in ghost files list

* Wed Feb 27 2008 Frederik Himpe <fhimpe@mandriva.org> 4.0.9-2mdv2008.1
+ Revision: 175897
- Update to bugfix release shorewall-perl-4.0.9.1

* Mon Feb 25 2008 Frederik Himpe <fhimpe@mandriva.org> 4.0.9-1mdv2008.1
+ Revision: 174942
- New upstream bugfix release

* Sat Feb 23 2008 Frederik Himpe <fhimpe@mandriva.org> 4.0.8-5mdv2008.1
+ Revision: 174093
- Add Conflicts to fix update from shorewall < 4.0 packages
  (files were moved from shorewall package to shorewall-common)

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 4.0.8-4mdv2008.1
+ Revision: 171106
- rebuild
- fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - fix ghost files one more time

* Sun Jan 27 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.8-2mdv2008.1
+ Revision: 158506
- fix permission of all ghost files
- add missing ghost files

* Sat Jan 26 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.8-1mdv2008.1
+ Revision: 158422
- update to latest release 4.0.8
- hardcode path to shorewall config files
- do not package config files twice, files in /etc/shorewall are sufficient

* Sat Jan 26 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.7-3mdv2008.1
+ Revision: 158257
- fix requires on iproute2
- shorewall package requires only shorewall-common and shorewall-perl, other subpackages are optional
- compile shorewal rules with perl compiler, as it is faster than shell one
- do the optimizations

* Fri Jan 25 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.7-2mdv2008.1
+ Revision: 158039
- add missing requires
- fix requires on subpackages
- make both initscripts mdv compiliant
- add missing scriplets
- use %%create_ghostfile
- fix permissions for initscripts and executables
- add ghost files for shorewall-lie

* Thu Jan 24 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.0.7-1mdv2008.1
+ Revision: 157724
- fix docs
- new version
- WARNING: big version jumps doesn't bring nothing good :)
- provide shorewall
  o common
  o lite
  o perl
  o shell
- fix file list, add %%ghost files
- better summaries and descriptions
- spec file clean
- TODO: provide patches for shorewall and shorewall-lite initscripts - cosmetics imho

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Oct 11 2007 Oden Eriksson <oeriksson@mandriva.com> 3.4.6-1mdv2008.1
+ Revision: 97137
- 3.4.6

  + Thierry Vignaud <tv@mandriva.org>
    - s/Mandrake/Mandriva/

* Sat Jun 30 2007 Olivier Blin <oblin@mandriva.com> 3.4.4-2mdv2008.0
+ Revision: 46098
- fix compiler script permissions (#31651)

* Wed Jun 27 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 3.4.4-1mdv2008.0
+ Revision: 44819
- spec file clean
- new version

* Thu May 17 2007 Olivier Blin <oblin@mandriva.com> 3.4.3-1mdv2008.0
+ Revision: 27675
- 3.4.3 (and package man pages)


* Tue Feb 13 2007 Olivier Blin <oblin@mandriva.com> 3.2.9-1mdv2007.0
+ Revision: 120417
- 3.2.9
- buildconflicts with apt-common so that shorewall build does not detect a Debian system
- bunzip init script

* Mon Nov 27 2006 Olivier Blin <oblin@mandriva.com> 3.2.6-1mdv2007.1
+ Revision: 87676
- 3.2.6
- Import shorewall

* Thu Aug 31 2006 Olivier Blin <blino@mandriva.com> 3.2.3-2mdv2007.0
- fix typo in changelog

* Thu Aug 31 2006 Olivier Blin <blino@mandriva.com> 3.2.3-1mdv2007.0
- 3.2.3 (this closes #24157)

* Sun Jul 23 2006 Olivier Blin <blino@mandriva.com> 3.2.1-1mdv2007.0
- 3.2.1
- drop bogons file ('nobogons' options has been eliminated in 3.0.0)

* Mon Jan 23 2006 Daouda LO <daouda@mandriva.com> 3.0.4-1mdk
- 3.0.4
- console friendly again (Tuomo Soini)

* Mon Dec 26 2005 Daouda LO <daouda@mandriva.com> 3.0.3-1mdk
- 3.0.3

* Wed Nov 30 2005 Daouda LO <daouda@mandriva.com> 3.0.2-1mdk
- 3.0.2

* Thu Nov 24 2005 Daouda LO <daouda@mandriva.com> 3.0.1-1mdk
- 3.0.1
- add Samples 
- cleanup spec
- Read The http://shorewall.net/pub/shorewall/3.0/shorewall-3.0.1/releasenotes.txt
  o Thu Nov 17 2005 Nicolas CHIPAUX <chipaux@mandriva.com> 3.0.0-1mdk
	- new version
    - cleaning spec
    - "clear" option in initscript is back
    - info about migration from 2.x to 3.x

* Fri Jul 22 2005 Daouda LO <daouda@mandrakesoft.com> 2.4.1-3mdk
- initscript priority from 25 to 10 (Michael Reinsch)
- refreshed link to firewall script (Oblin)

* Tue Jul 19 2005 Olivier Blin <oblin@mandriva.com> 2.4.1-2mdk
- enable shorewall startup

* Tue Jul 19 2005 Daouda LO <daouda@mandrakesoft.com> 2.4.1-1mdk
- Fix for security vulnerability in MACLIST processing
- Support for multiple internet interfaces to different ISPs
- Support for ipset
- updated firewall script and bogons list 
- back to shorewall genuine initscipt

* Mon Jul 11 2005 Olivier Blin <oblin@mandriva.com> 2.0.8-3mdk
- fix typo in init script to have chkconfig working again (#16657)

* Sat Apr 02 2005 Luca Berra <bluca@vodka.it> 2.0.8-2mdk
- use %%mkrel macro
- update firewall script from shorewall errata
- update bogons file from shorewall errata

* Thu Aug 26 2004 Florin <florin@mandrakesoft.com> 2.0.8-1mdk
- 2.0.8

* Thu Aug 05 2004 Florin <florin@mandrakesoft.com> 2.0.7-1mdk
- 2.0.7

* Wed Jun 30 2004 Florin <florin@mandrakesoft.com> 2.0.3a-1mdk
- 2.0.3a
- security update

* Fri Jun 25 2004 Florin <florin@mandrakesoft.com> 2.0.3-1mdk
- 2.0.3

* Sun Jun 13 2004 Florin <florin@mandrakesoft.com> 2.0.2f-1mdk
- 2.0.2f
- add the docs source
- remove the already present bogons and rf1918 files

* Thu Jun 03 2004 Florin <florin@mandrakesoft.com> 2.0.2d-1mdk
- 2.0.2d

* Tue May 18 2004 Florin <florin@mandrakesoft.com> 2.0.2a-1mdk
- 2.0.2a
- add the initdone file

* Fri May 14 2004 Florin <florin@mandrakesoft.com> 2.0.2-0.RC1.1mdk
- 2.0.2-RC1
- remove the already intergrated kernel-suffix patch

* Thu Apr 22 2004 Florin <florin@mandrakesoft.com> 2.0.1-3mdk
- add the bogons and rf1918 sources (thx to T. Backlund)

* Tue Apr 20 2004 Florin <florin@mandrakesoft.com> 2.0.1-2mdk
- add the kernel modules extension patch (bug #9311)
- the same patch fixes the Mandrake broken insmod (uses modprobe instead)

* Tue Apr 20 2004 Florin <florin@mandrakesoft.com> 2.0.1-1mdk
- 2.0.1
- samples 2.0.1
- add the netmap file

* Wed Mar 24 2004 Florin <florin@mandrakesoft.com> 2.0.0b-1mdk
- 2.0.0b

* Sat Mar 20 2004 Florin <florin@mandrakesoft.com> 2.0.0a-1mdk
- 2.0.0a
- samples 2.0.0

